@@ -70,9 +70,13 @@ class Coordinator:
         return os.path.join(self.configuration.dump_folder, 'coordinator_schema.sql')
 
     @property
-    def schema_constraint_path(self):
+    def coordinator_constraint_path(self):
         return os.path.join(self.configuration.dump_folder, 'coordinator_constraints.sql')
 
+    @property
+    def workers_constraint_path(self):
+        return os.path.join(self.configuration.dump_folder, 'workers_constraints.sql')
+
     @property
     def distribute_path(self):
         return os.path.join(self.configuration.dump_folder, 'coordinator_distribute.sql')
@@ -98,9 +102,18 @@ class Coordinator:
         }
 
     @property
-    def constraint_dump_statement(self):
-        return self.base_dump_statement + ' --section=post-data --file=%(file)s'  % {
-            'file': self.schema_constraint_path,
+    def coordinator_constraint_dump_statement(self):
+        return self.base_dump_statement + ' --section=post-data --file=%(file)s %(ignore_tables)s'  % {
+            'file': self.coordinator_constraint_path,
+            'ignore_tables': ' '.join(['-T %s' % table.name for table in self.distributed_tables + self.reference_tables])
+        }
+
+    @property
+    def workers_constraint_dump_statement(self):
+        tables = ['-t %s' % table.name for table in self.distributed_tables + self.reference_tables]
+        return self.base_dump_statement + ' --section=post-data --file=%(file)s %(tables)s'  % {
+            'file': self.workers_constraint_path,
+            'tables': ' '.join(tables)
         }
 
     @property
