@@ -1,6 +1,7 @@
 import datetime
 import os
 import psycopg2
+from .utils import run_statements_in_parallel
 
 
 def dump_schema(coordinator):
@@ -10,8 +11,12 @@ def dump_schema(coordinator):
     print('%s: Finished schema dump' % datetime.datetime.now())
 
     print('%s: Executing %s' % (datetime.datetime.now(),
-                                coordinator.constraint_dump_statement))
-    os.system(coordinator.constraint_dump_statement)
+                                coordinator.coordinator_constraint_dump_statement))
+    os.system(coordinator.coordinator_constraint_dump_statement)
+    print('%s: Executing %s' % (datetime.datetime.now(),
+                                coordinator.workers_constraint_dump_statement))
+    os.system(coordinator.workers_constraint_dump_statement)
+
     print('%s: Finished constraints dump' % datetime.datetime.now())
 
     dump_path = coordinator.distribute_path
@@ -103,9 +108,13 @@ def restore_coordinator_sequences(coordinator):
 
 def restore_coordinator_constraints(coordinator):
     print('Restore sequences on new coordinator')
-    command = 'psql "%s" -c "\\timing" -a -f %s' % (coordinator.connection_string,
-                                                    coordinator.schema_constraint_path)
-    os.system(command)
+    commands = ['psql "%s" -c "\\timing" -a -f %s' % (coordinator.connection_string,
+                                                      coordinator.coordinator_constraint_path),
+                'psql "%s" -c "\\timing" -a -f %s' % (coordinator.connection_string,
+                                                      coordinator.workers_constraint_path)
+                ]
+
+    run_statements_in_parallel(coordinator.configuration, commands)
 
 def execute_lock_transactions(coordinator, cursor):
     for statement in coordinator.lock_statements:
